@@ -573,7 +573,7 @@ divBasic <- function (infile = NULL, outfile = NULL, gp = 3, bootstraps = NULL,
   
   if (!is.null(outfile)){
     #write_res<-is.element("xlsx",installed.packages()[,1])
-    if(require("xlsx")){
+    if ("xlsx" %in% rownames(installed.packages())) {
       xlsx::write.xlsx(writeOut, file = paste(of, "[divBasic].xlsx", sep = ""),
                        sheetName = "Basic stats", col.names = FALSE,
                        row.names = FALSE, append=FALSE)
